"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const handlebars = require("handlebars");
const TEMPLATE = `/**
 * Autogenerated, do not modify
 */
import * as Knex from "knex";
{{#each imports}}{{this}}{{/each}}

export default class Inserter {
    constructor(private knex:Knex){

    }

    async insert<T>(tableName:string, data:T) {
        let q =  this.knex(tableName).insert(data);
        try {
            return await this.knex(tableName).insert(data);
        } catch (error) {
            console.log(q.toString());            
        }
    }    

    async batchInsert<T>(tableName:string, arr:T[]) {
		let chunkSize = 1000;
		await this.knex.batchInsert(tableName, arr, chunkSize);
    }

{{#each inserters}}{{this}}{{/each}}

{{#each batchInserters}}{{this}}{{/each}}
}`;
const INSERT_TEMPLATE = `
    async insert{{className}}(item:{{className}}):Promise<{{className}}>{
        return await this.insert("{{tableName}}", item);
    }
`;
const BATCH_INSERT_TEMPLATE = `
    async insert{{className}}(item:{{className}}):Promise<{{className}}>{
        return await this.insert("{{tableName}}", item);
    }
`;
class InserterBuilder {
    constructor() {
        this.compiledTemplate = handlebars.compile(TEMPLATE);
        this.compiledInsertTemplate = handlebars.compile(INSERT_TEMPLATE);
        this.compiledBatchInsertTemplate = handlebars.compile(BATCH_INSERT_TEMPLATE);
    }
    renderInserter(tables) {
        let input = {
            inserters: tables.map(t => this.compiledInsertTemplate(t)),
            batchInserters: tables.map(t => this.compiledBatchInsertTemplate(t)),
            imports: tables.map(t => this.renderImportRow(t))
        };
        return this.compiledTemplate(input);
    }
    renderImportRow(table) {
        table = JSON.parse(JSON.stringify(table));
        table.filename = table.filename.replace(".ts", "");
        return `import {${table.className}} from "./${table.filename}"`;
    }
}
exports.InserterBuilder = InserterBuilder;
//# sourceMappingURL=inserter-builder.js.map