"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const handlebars = require("handlebars");
const LINE = "let query = `CALL ${name}(${questionMarks});`;   ";
const template = `import * as Knex from "Knex";
export default class StoredProcedures {
  constructor(private knex:Knex){

  }

  async callSp(name: string, ...args:any[]):Promise<any>{
    let questionMarks = args.map(item => "?").join(", ");
    ${LINE}
    let resp = await this.knex.raw(query,args);
    return resp[0][0];
  }

  async sp_orders_stat_left_menu(a:number, b:string):Promise<any>{
    return await this.callSp("sp_orders_stat_left_menu", a,b);
  }

  {{#each strFunctions}}{{this}}{{/each}}
}
`;
const fnTemplate = `
  async {{name}}({{typeNameList}}):Promise<any>{
    return await this.callSp("{{name}}", {{commaSepParamNames}});
  }
`;
class SpBuilder {
    constructor(procedures, types) {
        this.procedures = procedures;
        this.types = types;
        this.compiledTemplate = handlebars.compile(template);
        this.compiledFunctionTemplate = handlebars.compile(fnTemplate);
    }
    renderTemplate() {
        let strFunctions = [];
        for (let key in this.procedures) {
            strFunctions.push(this.renderFunction(key, this.procedures[key]));
        }
        let input = { strFunctions: strFunctions };
        let output = this.compiledTemplate(input);
        return output;
    }
    getMySqlType(param) {
        return this.types[param.dataType];
    }
    toTsParamNotation(param) {
        return param.parameterName + ": " + this.getMySqlType(param);
    }
    renderFunction(name, procedure) {
        let params = [];
        for (let key in procedure) {
            params.push(procedure[key]);
        }
        params = params.filter(p => p.parameterMode == "IN");
        params.sort((a, b) => { return a.ordinalPosition - b.ordinalPosition; });
        let commaSepParamNames = params.map(p => p.parameterName).join(", ");
        let typeNameList = params.map(p => this.toTsParamNotation(p)).join(", ");
        let input = { name: name, typeNameList: typeNameList, commaSepParamNames: commaSepParamNames };
        return this.compiledFunctionTemplate(input);
    }
}
exports.default = SpBuilder;
//# sourceMappingURL=sp-builder.js.map